summaryrefslogtreecommitdiffstats
path: root/src/usr/expaccess
diff options
context:
space:
mode:
authorMike Baiocchi <mbaiocch@us.ibm.com>2019-04-19 08:49:20 -0500
committerChristian R. Geddes <crgeddes@us.ibm.com>2019-05-16 11:07:15 -0500
commit4f842cf1d6febb37ca7917e40a9fb0a1e9e3e6e4 (patch)
tree478a17720159c864be8faab70692906fa74016fb /src/usr/expaccess
parent686bbf502fc63b486fb54816e3f7d4e7a7ce6bd7 (diff)
downloadblackbird-hostboot-4f842cf1d6febb37ca7917e40a9fb0a1e9e3e6e4.tar.gz
blackbird-hostboot-4f842cf1d6febb37ca7917e40a9fb0a1e9e3e6e4.zip
Combine 'generic' and 'explorer' OCMB chip targets
This commit moves the Explorer-specific OCMB_CHIP target into the 'generic' OCMB_CHIP target so that there is only one target. This target will also be used for Gemini. Changes were also made to look for Gemini vs Explorer where appropriate based on ATTR_CHIP_ID. Change-Id: I91b79195bf997a6af4e2ae0a3326ed5a1c7887ec RTC:205563 Reviewed-on: http://rchgit01.rchland.ibm.com/gerrit1/77220 Tested-by: Jenkins Server <pfd-jenkins+hostboot@us.ibm.com> Tested-by: Jenkins OP Build CI <op-jenkins+hostboot@us.ibm.com> Tested-by: FSP CI Jenkins <fsp-CI-jenkins+hostboot@us.ibm.com> Tested-by: Jenkins OP HW <op-hw-jenkins+hostboot@us.ibm.com> Reviewed-by: Glenn Miles <milesg@ibm.com> Reviewed-by: William G. Hoffa <wghoffa@us.ibm.com> Reviewed-by: Christian R. Geddes <crgeddes@us.ibm.com>
Diffstat (limited to 'src/usr/expaccess')
-rw-r--r--src/usr/expaccess/expscom_utils.C15
1 files changed, 8 insertions, 7 deletions
diff --git a/src/usr/expaccess/expscom_utils.C b/src/usr/expaccess/expscom_utils.C
index 5ea7eeeb2..c4818379c 100644
--- a/src/usr/expaccess/expscom_utils.C
+++ b/src/usr/expaccess/expscom_utils.C
@@ -55,20 +55,21 @@ errlHndl_t validateInputs(DeviceFW::OperationType i_opType,
errlHndl_t l_err = nullptr;
uint32_t l_commonPlid = 0; // If there are multiple issues found link logs with first
- TARGETING::ATTR_MODEL_type l_targetModel =
- i_target->getAttr<TARGETING::ATTR_MODEL>();
+ // Verify that the target is of type OCMB_CHIP
+ TARGETING::ATTR_TYPE_type l_targetType =
+ i_target->getAttr<TARGETING::ATTR_TYPE>();
- // Only target we can perform ocmb scoms on are explorer OCMB chip targets
- if( l_targetModel != TARGETING::MODEL_EXPLORER )
+ // Only target we can perform ocmb scoms on are OCMB chip targets
+ if( l_targetType != TARGETING::TYPE_OCMB_CHIP )
{
- TRACFCOMP( g_trac_expscom, ERR_MRK "validateInputs> Invalid target type : l_targetModel=%d", l_targetModel );
+ TRACFCOMP( g_trac_expscom, ERR_MRK "validateInputs> Invalid target type : l_targetType=0x%X", l_targetType );
/*@
* @errortype
* @moduleid EXPSCOM::MOD_OCMB_UTILS
* @reasoncode EXPSCOM::RC_INVALID_MODEL_TYPE
* @userdata1 SCOM Address
* @userdata2 Model Type
* @devdesc validateInputs> Invalid target type (!= OCMB_CHP)
* @custdesc A problem occurred during the IPL of the system:
* Invalid target type for a SCOM operation.
*/
@@ -76,7 +77,7 @@ errlHndl_t validateInputs(DeviceFW::OperationType i_opType,
EXPSCOM::MOD_OCMB_UTILS,
EXPSCOM::RC_INVALID_MODEL_TYPE,
i_scomAddr,
- l_targetModel,
+ l_targetType,
ERRORLOG::ErrlEntry::ADD_SW_CALLOUT);
l_err->collectTrace(EXPSCOM_COMP_NAME);
OpenPOWER on IntegriCloud
@@ -55,20 +55,21 @@ errlHndl_t validateInputs(DeviceFW::OperationType i_opType,
* @userdata1 SCOM Address
* @userdata2 Model Type
- * @devdesc validateInputs> Invalid target type (!= OCMB_CHP)
+ * @devdesc validateInputs> Invalid target type (!= OCMB_CHIP)
* @custdesc A problem occurred during the IPL of the system:
* Invalid target type for a SCOM operation.